@@ -139,6 +139,8 @@ def insert_one_row_into_table_q_asset_inventory_software_os_unique(
                         osname = str(asset_item_dict['operatingSystem']['osName'])
                 if 'lifecycle' in software_item:
                     lifecycle = software_item['lifecycle']
+                    if lifecycle is None:
+                        lifecycle = {}
                 else:
                     lifecycle = {}
                 if 'isIgnored' in software_item:
