@@ -337,37 +337,37 @@ class DisplayCounterToLog:
 
 def log_system_information(logger_method=print, data_directory="/opt/qetl/users"):
     logger_method(
-        f'SYS STAT: CPU percent usage={psutil.cpu_percent(interval=0.5)}, '
+        f'SYS STAT: CPU usage={psutil.cpu_percent(interval=0.5)} %, '
         f'frequency='
-        f'{get_cpu_frequency()}%, '
+        f'{get_cpu_frequency()} MHz, '
         f'count='
-        f'{get_cpu_count()}, '
+        f'{get_cpu_count()}'
     )
     logger_method(
-        f'SYS STAT: RAM percent usage='
-        f'{get_ram_usage_pct()}, '
+        f'SYS STAT: RAM usage='
+        f'{get_ram_usage_pct()} %, '
         f'total='
         f'{get_ram_size_total_in_mb():,.0f} MB, '
         f'used='
         f'{get_ram_size_usage_in_mb():,.0f} MB, '
         f'available='
-        f'{get_ram_size_available_in_mb():,.0f} MB, '
+        f'{get_ram_size_available_in_mb():,.0f} MB '
     )
     logger_method(
-        f'SYS STAT: SWAP percent usage='
-        f'{get_swap_usage_pct()}, '
+        f'SYS STAT: SWAP usage='
+        f'{get_swap_usage_pct()} %, '
         f'total='
         f'{get_swap_total_in_mb():,.0f} MB, '
         f'used='
         f'{get_swap_usage_in_mb():,.0f} MB, '
         f'available='
-        f'{get_swap_available_in_mb():,.0f} MB, '
+        f'{get_swap_available_in_mb():,.0f} MB '
     )
 
     try:
         logger_method(
-            f'SYS STAT: DISK percent usage='
-            f'{get_disk_size_pct(data_dir=data_directory)}, '
+            f'SYS STAT: DISK usage='
+            f'{get_disk_size_pct(data_dir=data_directory)} %, '
             f'total='
             f'{get_disk_size_total(data_dir=data_directory):,.0f} MB, '
             f'used='
@@ -390,10 +390,26 @@ def if_disk_space_usage_greater_than_90_log_warning(logger_method=print, data_di
         pass
 
 
-def if_ram_space_size_less_than_8_gig_log_warning(logger_method=print):
+def if_swap_space_total_is_zero_abort(logger_method=print):
+    if int(get_swap_total_in_mb()) > 0:
+        pass
+    else:
+        logger_method(f'SYS ERROR: Please contact your systems administrator to configure swap space.')
+        logger_method(f'SYS ERROR: current swap space size is: {get_swap_total_in_mb():,.0f} MB, ')
+        exit(1)
+
+
+def if_swap_space_total_is_low_log_warning(logger_method=print):
+    if int(get_swap_total_in_mb()) < 4000:
+        logger_method(f'SYS WARNING: SWAP size total is < 4 Gig. '
+                      f'Consider increasing SWAP to support larger batch jobs and sql queries')
+
+
+def if_ram_space_size_is_low_log_warning(logger_method=print):
     ram_size_total_in_mb = int(get_ram_size_total_in_mb())
     if ram_size_total_in_mb < 8100:
-        logger_method(f'SYS WARNING: DISK size usage < 8 Gig.  Consider increasing RAM to 16 Gig for ETL')
+        logger_method(f'SYS WARNING: RAM size total < 8 Gig.  '
+                      f'Consider increasing RAM to support larger batch jobs and sql queries')
 
 
 def proc_table(logger_method=print):
